@@ -37,6 +37,7 @@ class TSPEnv(gym.Env):
         
         
     def reset(self, seed=None, options={}) -> np.array:
+        
         super().reset(seed=seed)
         random.seed(seed)
         np.random.seed(seed)
@@ -58,11 +59,11 @@ class TSPEnv(gym.Env):
         
         self.optimal_solution = 0
         if self.is_eval_env == True:
-            self.optimal_cycle = nx.approximation.traveling_salesman_problem(G, weight='weight', cycle=False)
+            self.optimal_cycle = nx.approximation.traveling_salesman_problem(G, weight='weight', cycle=True)
             for i in range(len(self.optimal_cycle)-1):
                 self.optimal_solution += G[self.optimal_cycle[i]][self.optimal_cycle[i+1]]['weight']
-        
-        
+            
+        print(self.optimal_solution)
         G = G.to_directed()
         
         x = np.zeros((self.n_nodes, 1), dtype=np.float32)
@@ -76,21 +77,8 @@ class TSPEnv(gym.Env):
         edge_f = np.array([G[u][v]['weight'] for u, v in G.edges], dtype=np.float32).reshape(-1, 1)
         self.graph = gym.spaces.GraphInstance(nodes=x, edges=edge_f, edge_links=edge_index)
          
-       
-        self.optimal_solution = 0
-        if self.is_eval_env == False:
-            self.optimal_cycle = nx.approximation.traveling_salesman_problem(G, weight='weight', cycle=False)
-            # self.optimal_cycle = nx.approximation.simulated_annealing_tsp(G, weight='weight', init_cycle=None,)
-            # self.optimal_cycle = nx.approximation.threshold_accepting_tsp(G, weight='weight', init_cycle=,)
-            # self.optimal_cycle = nx.approximation.greedy_tsp(G, weight='weight')
-            # print(self.optimal_cycle)
-            for i in range(len(self.optimal_cycle)-1):
-                self.optimal_solution += G[self.optimal_cycle[i]][self.optimal_cycle[i+1]]['weight']
-        print(self.optimal_solution)
-
         self.total_solution_cost = 0
         
-        
         info = {'mask': self._get_mask()}
         
         if self.return_graph_obs:
@@ -109,7 +97,8 @@ class TSPEnv(gym.Env):
     def _get_mask(self) -> np.array:
         mask = np.zeros((self.n_nodes,), dtype=bool)
         mask[self._get_neighbors(self.head)] = 1
-        mask[self.graph.nodes[:, self.NODE_TAKEN] == 1] = 0
+        # mask[self.graph.nodes[:, self.NODE_TAKEN] == 1] = 0
+        
         return mask
     
     def step(self, action: int) -> Tuple[gym.spaces.GraphInstance, SupportsFloat, bool, bool, dict]:
@@ -118,25 +107,27 @@ class TSPEnv(gym.Env):
         assert self._get_mask()[action] == True, f"Mask of {action} is False!"
 
         assert action in self._get_neighbors(self.head), f"Node {action} is not a neighbor of the current path head {self.head}!"
-        assert np.isclose(self.graph.nodes[action, self.NODE_TAKEN], 1) == False, f"Node {action} is already a part of the path!"
+        # assert np.isclose(self.graph.nodes[action, self.NODE_TAKEN], 1) == False, f"Node {action} is already a part of the path!"
         
         
         done = False
-        if not self.weighted:
-            reward = 1 
-        else:
-            reward = 1-self.adj[self.head, action]
-            
+        # if not self.weighted:
+        #     reward = 1 
+        # else:
+        #     reward = 1-self.adj[self.head, action]
+        
+        reward = -self.adj[self.head, action]
+        
         self.total_solution_cost += self.adj[self.head, action]
         info = {}
         
+        
         self.graph.nodes[action, self.NODE_TAKEN] = 1
         self.head = action
         
-        
         if np.isclose(self.graph.nodes[:, self.NODE_TAKEN], 0).any() == False:    
             done = True
-            reward += self.n_nodes
+            # reward += self.n_nodes
             info['solved'] = True
         
         
